@@ -35,18 +35,18 @@ def annual_anomaly(self, baseline=None, metric="absolute", window=1):
     If you wanted to calculate an annual anomaly where values are compared with the mean for the years
     1950-1969, you would do this:
 
-    >>> data.annual_anomaly(baseline = [1950, 1969])
+    >>> ds.annual_anomaly(baseline = [1950, 1969])
 
     By default, this results in the absolute difference to be used. If you wanted the anomaly to be calculated
     relative to the baseline mean, you would do this:
 
-    >>> data.annual_anomaly(baseline = [1950, 1969], metric = "relative")
+    >>> ds.annual_anomaly(baseline = [1950, 1969], metric = "relative")
 
     You might want to smooth out the anomalies, so that you are looking at rolling averages. In that case you can
     supply a windows. So if you wanted to calculate the anomaly using a rolling average with a 10 year window, you
     would do this:
 
-    >>> data.annual_anomaly(baseline = [1950, 1969], window = 10)
+    >>> ds.annual_anomaly(baseline = [1950, 1969], window = 10)
 
 
     """
@@ -147,7 +147,7 @@ def monthly_anomaly(self, baseline=None):
     If you wanted to calculate a monthly anomaly where values are compared with the climatological monthly mean
     for the years 1950-1969, you would do this:
 
-    >>> data.monthly_anomaly(baseline = [1950, 1969])
+    >>> ds.monthly_anomaly(baseline = [1950, 1969])
 
     """
 
