@@ -13,7 +13,7 @@ from nctoolkit.session import (
     session_info,
     append_safe,
     remove_safe,
-    get_protected
+    get_protected,
 )
 from nctoolkit.temp_file import temp_file
 
@@ -119,7 +119,7 @@ def run_nco(command, target, out_file=None, overwrite=False):
             )
             result1, ignore = out.communicate()
             if "ERROR" in str(result1):
-                remove_safet(target)
+                remove_safe(target)
                 raise ValueError(
                     str(result1).replace("b'", "").replace("\\n", "").replace("'", "")
                 )
